from django.shortcuts import render, redirect
from django.contrib.auth import login
from django.contrib.auth.models import User
from django.http import JsonResponse
import csv
import os

# Fichier CSV pour stocker les scores
CSV_FILE = "scores.csv"

def init_csv():
    if not os.path.exists(CSV_FILE):
        with open(CSV_FILE, 'w', newline='') as file:
            writer = csv.writer(file)
            writer.writerow(["username", "score"])

def read_scores():
    scores = {}
    try:
        with open(CSV_FILE, 'r') as file:
            reader = csv.reader(file)
            next(reader)  # Ignorer l'en-tête
            for row in reader:
                scores[row[0]] = int(row[1])
    except FileNotFoundError:
        init_csv()
    return scores

def update_score(username, points):
    scores = read_scores()
    scores[username] = scores.get(username, 0) + points
    with open(CSV_FILE, 'w', newline='') as file:
        writer = csv.writer(file)
        writer.writerow(["username", "score"])
        for user, score in scores.items():
            writer.writerow([user, score])

def login_view(request):
    if request.method == "POST":
        username = request.POST["username"]
        user, created = User.objects.get_or_create(username=username)
        login(request, user)
        return redirect("challenges")
    return render(request, "login.html")

def challenges_view(request):
    if not request.user.is_authenticated:
        return redirect("login")
    challenges = ["Monter les escaliers", "1h de bureau debout", "Faire 5000 pas"]
    return render(request, "challenges.html", {"challenges": challenges})

def complete_challenge(request):
    if request.method == "POST":
        challenge_points = {
            "Monter les escaliers": 100,
            "1h de bureau debout": 50,
            "Faire 5000 pas": 200
        }
        challenge = request.POST.get("challenge")
        if challenge in challenge_points:
            update_score(request.user.username, challenge_points[challenge])
        return JsonResponse({"success": True})

def ranking_view(request):
    scores = read_scores()
    sorted_scores = sorted(scores.items(), key=lambda x: x[1], reverse=True)
    return render(request, "ranking.html", {"scores": sorted_scores})
